# Load packages
library(tidyverse)
library(xfun)

# Read raw data files
data_november <- read_csv("Data/all_apps_wide_2020-11-29.csv")
data_february <- read_csv("Data/all_apps_wide_2021-02-10.csv", guess_max = 2000)

# november data
# rename id variables
data_november <- rename(data_november,
                        old_id_1 = prolific_id.1.player.prolific_id,
                        old_id_2 = prisoner_dilemma_pre_matching_delayed_feedback_results.1.player.prolific_id,
                        old_id_3 = prisoner_dilemma_post_matching_delayed_feedback_results.1.player.prolific_id)

# create a keyed table of prolific ids / replacement ids
lookup <- data.frame(prolific=as.factor(data_november$old_id_1), 
                     new_id = as.numeric(as.factor(data_november$old_id_1)))
lookup <- filter(lookup, prolific != "" | !is.na(prolific))
lookup$prolific <- as.character(lookup$prolific)
lookup <- filter(lookup, xfun::is_ascii(prolific)== T)
lookup <- subset(lookup, nchar(prolific) > 5)

# replace prolific variables with new values
data_november <- left_join(data_november, lookup,
  by = c("old_id_1" = "prolific"))
data_november <- rename(data_november, new_id_1 = new_id)
data_november <- left_join(data_november, lookup,
                           by = c("old_id_2" = "prolific"))
data_november <- rename(data_november, new_id_2 = new_id)
data_november <- left_join(data_november, lookup,
                           by = c("old_id_3" = "prolific"))
data_november <- rename(data_november, new_id_3 = new_id)

# february data
# rename id variables
data_february <- rename(data_february,
                        old_id_1 = prolific_id.1.player.prolific_id,
                        old_id_2 = prisoner_dilemma_pre_matching_delayed_feedback_results.1.player.prolific_id,
                        old_id_3 = prisoner_dilemma_post_matching_delayed_feedback_results.1.player.prolific_id)

# create a keyed table of prolific ids / replacement ids
lookup <- data.frame(prolific=as.factor(data_february$old_id_1), 
                     new_id = as.numeric(as.factor(data_february$old_id_1)))
lookup$new_id <- lookup$new_id+1000
lookup <- filter(lookup, prolific != "" | !is.na(prolific))
lookup$prolific <- as.character(lookup$prolific)
lookup <- filter(lookup, xfun::is_ascii(prolific)== T)
lookup <- subset(lookup, nchar(prolific) > 5)

# replace prolific variables with new values
data_february <- left_join(data_february, lookup,
                           by = c("old_id_1" = "prolific"))
data_february <- rename(data_february, new_id_1 = new_id)
data_february <- left_join(data_february, lookup,
                           by = c("old_id_2" = "prolific"))
data_february <- rename(data_february, new_id_2 = new_id)
data_february <- left_join(data_february, lookup,
                           by = c("old_id_3" = "prolific"))
data_february <- rename(data_february, new_id_3 = new_id)

# remove old id variables
# november
data_november <- select(data_november, -old_id_1, -old_id_2, -old_id_3)
# february
data_february <- select(data_february, -old_id_1, -old_id_2, -old_id_3)

# write new data files
write.csv(data_november, "Data/all_apps_wide_2020-11-29_no_id.csv")
write.csv(data_february, "Data/all_apps_wide_2021-02-10_no_id.csv")

